@@ -6,7 +6,7 @@ use strict;
 
 use Exporter;
 
-$Locale::Currency::Format::VERSION = '1.26';
+$Locale::Currency::Format::VERSION = '1.29';
 
 @Locale::Currency::Format::ISA     = qw(Exporter);
 @Locale::Currency::Format::EXPORT  = qw(
@@ -355,13 +355,13 @@ sub format_negative {
 #        name frac_len thou_sep dec_sep space_sep utf_sym htm_sym com_sym pre
 %currency = (
 AED => ["UAE Dirham",2,",","."," ",$EMPTY,$EMPTY,"Dhs.",1],
-AFA => ["Afghani",0,$EMPTY,$EMPTY,"\x{060B}","&#060B;",,$EMPTY,$EMPTY],
+AFA => ["Afghani",0,$EMPTY,$EMPTY,"\x{060B}","&#x060B;",,$EMPTY,$EMPTY],
 ALL => ["Lek",2,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 AMD => ["Armenian Dram",2,",",".","",$EMPTY,$EMPTY,"AMD",0],
 ANG => ["Antillian Guilder",2,".",","," ","\x{0192}","&#x0192;","NAf.",1],
 AON => ["New Kwanza",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 ARS => ["Argentine Peso",2,".",",","","\x{20B1}","&#x20B1;","\$",1],
-ATS => ["Schilling",2,".",","," ",$EMPTY,$EMPTY,"S",1],
+ATS => ["Schilling",2,".",","," ",$EMPTY,$EMPTY,"öS",1],
 AUD => ["Australian Dollar",2," ",".","","\x{0024}","&#x0024;","\$",1],
 AWG => ["Aruban Guilder",2,",","."," ","\x{0192}","&#x0192;","AWG",1],
 AZN => ["Azerbaijanian Manat",2,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,"m",$EMPTY],
@@ -369,7 +369,7 @@ BAM => ["Convertible Marks",2,",",".","",$EMPTY,$EMPTY,"AZM",0],
 BBD => ["Barbados Dollar",2,$EMPTY,$EMPTY,"","\x{0024}","&#x0024;",$EMPTY,$EMPTY],
 BDT => ["Taka",2,",","."," ",$EMPTY,$EMPTY,"Bt.",1],
 BEF => ["Belgian Franc",0,".",""," ","\x{20A3}","&#x20A3;","BEF",1],
-BGL => ["Lev",2," ",","," ",$EMPTY,$EMPTY,"lv",0],
+BGN => ["Lev",2," ",","," ",$EMPTY,$EMPTY,"lv",0],
 BHD => ["Bahraini Dinar",3,",","."," ",$EMPTY,$EMPTY,"BD",1],
 BIF => ["Burundi Franc",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 BMD => ["Bermudian Dollar",2,",",".","","\x{0024}","&#x0024;","\$",1],
@@ -387,10 +387,10 @@ CHF => ["Swiss Franc",2,"'","."," ",$EMPTY,$EMPTY,"SFr.",1],
 CLP => ["Chilean Peso",0,".","","","\x{20B1}","&#x20B1;","\$",1],
 CNY => ["Yuan Renminbi",2,",",".","","\x{5713}","&#x5713;","Y",1],
 COP => ["Colombian Peso",2,".",",","","\x{20B1}","&#x20B1;","\$",1],
-CRC => ["Costa Rican Colon",2,".",","," ","\x{20A1}","&#x20A1;","\x{20A1}",1],
+CRC => ["Costa Rican Colon",2,".",","," ","\x{20A1}","&#x20A1;","₡",1],
 CUP => ["Cuban Peso",2,",","."," ","\x{20B1}","&#x20B1;","\$",1],
 CVE => ["Cape Verde Escudo",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-CYP => ["Cyprus Pound",2,".",",","","\x{00A3}","&#x00A3;","\x{00A3}",1],
+CYP => ["Cyprus Pound",2,".",",","","\x{00A3}","&#x00A3;","£",1],
 CZK => ["Czech Koruna",2,".",","," ",$EMPTY,$EMPTY,"Kc",0],
 DEM => ["Deutsche Mark",2,".",",","",$EMPTY,$EMPTY,"DM",0],
 DJF => ["Djibouti Franc",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
@@ -408,10 +408,10 @@ FIM => ["Markka",2," ",","," ",$EMPTY,$EMPTY,"mk",0],
 FJD => ["Fiji Dollar",0,$EMPTY,$EMPTY,"","\x{0024}","&#x0024;",$EMPTY,$EMPTY],
 FKP => ["Pound",0,$EMPTY,$EMPTY,"","\x{00A3}","&#x00A3;",$EMPTY,$EMPTY],
 FRF => ["French Franc",2," ",","," ","\x{20A3}","&#x20A3;","FRF",0],
-GBP => ["Pound Sterling",2,",",".","","\x{00A3}","&#x00A3;","",1],
+GBP => ["Pound Sterling",2,",",".","","\x{00A3}","&#x00A3;","£",1],
 GEL => ["Lari",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-GHS => ["Cedi",2,",",".","","\x{20B5}","&#20B5;","\x{20B5}",1],
-GIP => ["Gibraltar Pound",2,",",".","","\x{00A3}","&#x00A3;","",1],
+GHS => ["Cedi",2,",",".","","\x{20B5}","&#x20B5;","₵",1],
+GIP => ["Gibraltar Pound",2,",",".","","\x{00A3}","&#x00A3;","£",1],
 GMD => ["Dalasi",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 GNF => ["Guinea Franc",$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 GRD => ["Drachma",2,".",","," ","\x{20AF}","&#x20AF;","GRD",0],
@@ -424,7 +424,7 @@ HRK => ["Kuna",2,".",","," ",$EMPTY,$EMPTY,"kn",0],
 HTG => ["Gourde",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 HUF => ["Forint",0,".",""," ",$EMPTY,$EMPTY,"Ft",0],
 IDR => ["Rupiah",0,".","","",$EMPTY,$EMPTY,"Rp.",1],
-IEP => ["Irish Pound",2,",",".","","\x{00A3}","&#x00A3;","",1],
+IEP => ["Irish Pound",2,",",".","","\x{00A3}","&#x00A3;","£",1],
 ILS => ["New Israeli Sheqel",2,",","."," ","\x{20AA}","&#x20AA;","NIS",0],
 INR => ["Indian Rupee",2,",",".","","\x{20A8}","&#x20A8;","Rs.",1],
 IQD => ["Iraqi Dinar",3,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
@@ -433,7 +433,7 @@ ISK => ["Iceland Krona",2,".",","," ",$EMPTY,$EMPTY,"kr",0],
 ITL => ["Italian Lira",0,".",""," ","\x{20A4}","&#x20A4;","L.",1],
 JMD => ["Jamaican Dollar",2,",",".","","\x{0024}","&#x0024;","\$",1],
 JOD => ["Jordanian Dinar",3,",","."," ",$EMPTY,$EMPTY,"JD",1],
-JPY => ["Yen",0,",","","","\x{00A5}","&#x00A5;","",1],
+JPY => ["Yen",0,",","","","\x{00A5}","&#x00A5;","¥",1],
 KES => ["Kenyan Shilling",2,",",".","",$EMPTY,$EMPTY,"Kshs.",1],
 KGS => ["Som",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 KHR => ["Riel",2,$EMPTY,$EMPTY,"","\x{17DB}","&#x17DB;",$EMPTY,$EMPTY],
@@ -463,7 +463,7 @@ MRO => ["Ouguiya",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 MTL => ["Maltese Lira",2,",",".","","\x{20A4}","&#x20A4;","Lm",1],
 MUR => ["Mauritius Rupee",0,",","","","\x{20A8}","&#x20A8;","Rs",1],
 MVR => ["Rufiyaa",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-MWK => ["Kwacha",2,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
+MWK => ["Kwacha",2,",",".","",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 MXN => ["Mexican Peso",2,",","."," ","\x{0024}","&#x0024;","\$",1],
 MYR => ["Malaysian Ringgit",2,",",".","",$EMPTY,$EMPTY,"RM",1],
 MZN => ["Metical",2,".",","," ",$EMPTY,$EMPTY,"Mt",0],
@@ -482,11 +482,11 @@ PHP => ["Philippine Peso",2,",",".","","\x{20B1}","&#x20B1;","PHP",1],
 PKR => ["Pakistan Rupee",2,",",".","","\x{20A8}","&#x20A8;","Rs.",1],
 PLN => ["Zloty",2," ",","," ",$EMPTY,$EMPTY,"zl",0],
 PTE => ["Portuguese Escudo",0,".",""," ",$EMPTY,$EMPTY,"Esc",0],
-PYG => ["Guarani",0,$EMPTY,$EMPTY,"","\x{20B2}","&#20B2;","Gs.",$EMPTY],
+PYG => ["Guarani",0,$EMPTY,$EMPTY,"","\x{20B2}","&#x20B2;","Gs.",$EMPTY],
 QAR => ["Qatari Rial",0,$EMPTY,$EMPTY,"","\x{FDFC}","&#xFDFC;",$EMPTY,$EMPTY],
 RON => ["Leu",2,".",","," ",$EMPTY,$EMPTY,"lei",0],
 RSD => ["Serbian Dinar",2,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,"din",0],
-RUB => ["Russian Ruble",2,".",",",$EMPTY,"\x{0440}\x{0443}\x{0431}","&#0440;&#0443;&#0431;","RUB",1],
+RUB => ["Russian Ruble",2,".",",",$EMPTY,"\x{0440}\x{0443}\x{0431}","&#x0440;&#x0443;&#x0431;","RUB",1],
 RWF => ["Rwanda Franc",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SAC => ["S. African Rand Commerc.",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SAR => ["Saudi Riyal",2,",","."," ","\x{FDFC}","&#xFDFC;","SR",1],
@@ -503,7 +503,7 @@ SLL => ["Leone",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SOS => ["Somali Shilling",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SRG => ["Surinam Guilder",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 STD => ["Dobra",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-SVC => ["El Salvador Colon",2,",",".","","\x{20A1}","&#x20A1;","\x{20A1}",1],
+SVC => ["El Salvador Colon",2,",",".","","\x{20A1}","&#x20A1;","¢",1],
 SYP => ["Syrian Pound",0,$EMPTY,$EMPTY,"","\x{00A3}","&#x00A3;",$EMPTY,$EMPTY],
 SZL => ["Lilangeni",2,"",".","",$EMPTY,$EMPTY,"E",1],
 THB => ["Baht",2,",","."," ","\x{0E3F}","&#x0E3F;","Bt",0],
@@ -699,7 +699,7 @@ The arguments to B<currency_set> are:
         Ex: currency_set('GBP', "\x{00A3}#,###.##", FMT_SYMBOL)
 
         If an HTML symbol is wanted, escape its equivalent HTML code.
-        Ex: currency_set('GBP', '&#00A3;#,###.##', FMT_HTML)
+        Ex: currency_set('GBP', '&#x00A3;#,###.##', FMT_HTML)
 
     FORMAT
         This argument is required if TEMPLATE is present.
